# Copyright (C) 2021 Elliot Killick <elliotkillick@zohomail.eu>
# Licensed under the MIT License. See LICENSE file for details.

%define vm_name qubes-video-companion

Name:           %{vm_name}-dom0
Version:        1.0.2
Release:        1%{?dist}
Summary:        Securely stream webcams and share screens across virtual machines

License:        MIT
URL:            https://github.com/elliotkillick/qubes-video-companion
Source0:        %{vm_name}-%{version}.tar.gz

BuildArch:      noarch

BuildRequires:  make
BuildRequires:  python3-setuptools
BuildRequires:  python3-devel

Requires:       gstreamer1-plugins-good

%description
Qubes Video Companion is a tool for securely streaming webcams and sharing
screens across virtual machines.

It accomplishes this by creating a uni-directional flow of raw video that is
passed from one virtual machine to another through file descriptors thereby
allowing both machines to be completely air-gaped with no networking stacks
exposed. This design makes the side of the video sending virtual machine 100%
immune to attack and only leaves a very small attack surface on the side of
the video receiving virtual machine.

The project emphasizes correctness and security all the while also sporting
superb performance by maintaining a small footprint of the available
computational resources and low latency even at Full HD and greater
resolutions at 30 or more frames per second.

This package contains only the video senders, Qubes RPC policies and
associated documentation components of Qubes Video Companion which are
necessary for dom0.

%prep
%autosetup -n %{vm_name}-%{version}

%build
# Enable Python 3 for Qubes R4.0 dom0 (Fedora 25) support because it defaults to Python 2
%define  __python %{__pythonX}
%make_build

%install
rm -rf $RPM_BUILD_ROOT
make DESTDIR=%{?buildroot} install-dom0 install-license

%files
%{_licensedir}/qubes-video-companion/LICENSE
%{_docdir}/qubes-video-companion/README.md
%{_docdir}/qubes-video-companion/pipeline.md
%{_docdir}/qubes-video-companion/visualizations/*
%{_sysconfdir}/qubes-rpc/qvc.Webcam
%{_sysconfdir}/qubes-rpc/qvc.ScreenShare
%{_sysconfdir}/qubes-rpc/policy/qvc.Webcam
%{_sysconfdir}/qubes-rpc/policy/qvc.ScreenShare
%{_datadir}/qubes-video-companion/sender/service.py
%{_datadir}/qubes-video-companion/sender/webcam.py
%{_datadir}/qubes-video-companion/sender/screenshare.py
%{_datadir}/qubes-video-companion/sender/tray_icon.py
%{python3_sitelib}/qvctests
%{python3_sitelib}/qvctests-*.egg-info

%changelog
* Tue Mar 14 2023 Qubes OS Team <qubes-devel@googlegroups.com>
- For complete changelog see: https://github.com/QubesOS/qubes-video-companion.git

* Tue Mar 14 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 8313497
- version 1.0.2-1

* Tue Mar 14 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 3021f41
- debian: only recommend v4l2loopback-dkms

* Tue Mar 14 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 1787d9f
- Fix typing hints

* Mon Jan 16 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 7b568f1
- version 1.0.1-1

* Sun Jan 15 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 313ce9b
- pylint: disable consider-using-f-string

* Thu Jan 12 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 038b4f8
- tests: webcam test is supposed to work now

* Thu Jan 12 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - ce725b8
- webcam: workaround gstreamer bug for video/x-raw source

* Thu Jan 12 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 741a487
- Drop --buffer-size=0, it doesn't do anything

* Thu Jan 12 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - dd8e6be
- tests: log more details on failure

* Thu Jan 12 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 9bb6481
- sender/webcam: support raw source stream too

* Wed Jan 11 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 9dafa4e
- Remove 'colorimetry' pipeline constraint

* Sun Sep 18 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - b3706f8
- ci: limit pylint to actual package

* Sun Sep 18 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - cb91413
- tests: add skeleton for webcam test too

* Sun Sep 18 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 14b44ce
- tests: add basic integration test for screen share

* Wed Jul 13 2022 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - f710822
- Add v4l-utils dependency

* Mon Jun 20 2022 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 82c1038
- Make pylint happy again

* Mon Jun 20 2022 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 683e401
- Reformat code according to python-black

* Mon Jun 20 2022 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 240c140
- Make pylint happy

* Mon Jun 20 2022 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 7800118
- Add .pylintrc from core-admin and fix deps

* Sat Jun 18 2022 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 58cf260
- Make shellcheck happy

* Sat Jun 18 2022 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - a790ea9
- Qubes Builder integration

* Sat Jun 18 2022 Frédéric Pierret (fepitre) <frederic.pierret@qubes-os.org> - 51f9c35
- Rework .gitlab-ci.yml

* Tue Apr 12 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - c7215ba
- Allow @default in the qrexec policies

* Tue Apr 12 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - e67ad19
- Use @default as the destination if none is passed

* Tue Apr 12 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 4939934
- Fix debian/rules

* Fri Apr 08 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 418a7c1
- Convert icon.png

* Fri Apr 08 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 695043a
- Make install a bit more robust

* Fri Apr 08 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 3c7d3cd
- Check for /etc/qubes-release in dom0

* Fri Apr 08 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 7af0651
- Avoid overbroad except

* Fri Apr 08 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 302352f
- Minor Python improvements

* Fri Apr 08 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 0b8b901
- Add basic comments to the qrexec policies

* Fri Apr 08 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - fb6db6f
- Don't hardcode dom0 as a destination

* Fri Apr 08 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - ca39b24
- Avoid tripping -o pipefail

* Fri Apr 08 2022 Demi Marie Obenour <demi@invisiblethingslab.com> - 43343bc
- Improve documentation

* Mon Nov 01 2021 Elliot Killick <elliotkillick@zohomail.eu> - 72cd1c6
- Small fix ups

* Thu Oct 14 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - d7804d3
- Improved packaging script

* Thu Oct 14 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - ed259e9
- Split the RPM package into separate packages

* Sun Oct 10 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - ce98c5d
- Mark various targets as .PHONY

* Sat Oct 09 2021 Demi Marie Obenour <demi@invisiblethingslab.com> - e81f522
- Avoid installing v4l2loopback scripts by default

* Mon Aug 09 2021 Elliot Killick <elliotkillick@zohomail.eu> - eb902bf
- build: simplify RPM spec copying

* Mon Aug 09 2021 Elliot Killick <elliotkillick@zohomail.eu> - a1ae610
- Update README

* Sat Aug 07 2021 Elliot Killick <elliotkillick@zohomail.eu> - dd8e22f
- Update README

* Sat Aug 07 2021 Elliot Killick <elliotkillick@zohomail.eu> - d178a85
- Update README

* Sat Aug 07 2021 Elliot Killick <elliotkillick@zohomail.eu> - 6255fcd
- Update Dom0 RPM spec

* Mon Jun 21 2021 Elliot Killick <elliotkillick@zohomail.eu> - 999ea16
- Update comment

* Mon Jun 21 2021 Elliot Killick <elliotkillick@zohomail.eu> - d2a04fe
- Fix missing variable syntax

* Mon Jun 21 2021 Elliot Killick <elliotkillick@zohomail.eu> - 336551c
- Add build scripts

* Mon Jun 21 2021 Elliot Killick <elliotkillick@zohomail.eu> - d9c052c
- Remove rpc-config file installation into dom0

* Fri Jun 18 2021 Elliot Killick <elliotkillick@zohomail.eu> - 2a0cbde
- Fix typos

* Fri Jun 18 2021 Elliot Killick <elliotkillick@zohomail.eu> - e6254d0
- Restructure project organization and update build

